==> styled-bootstrap-0.1.7-0.tgz: package/lib/Progress/Progress.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: flex;\n  overflow: hidden; // force rounded corners by cropping it\n  font-size: ', ';\n  line-height: ', ';\n  text-align: center;\n  background-color: ', ';\n  ', ';\n  ', ';\n'], ['\n  display: flex;\n  overflow: hidden; // force rounded corners by cropping it\n  font-size: ', ';\n  line-height: ', ';\n  text-align: center;\n  background-color: ', ';\n  ', ';\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React, { cloneElement } from 'react';
import styled from 'styled-components';
// import PropTypes from 'prop-types';

import { borderRadius } from '../utils/src/border-radius';
import { boxShadow } from '../utils/src/box-shadow';

import ProgressBar from './ProgressBar';

import themeProp from '../utils/src/theme';

import { progressHeight, progressFontSize, progressBg, progressBorderRadius, progressBoxShadow } from './default-theme';

var StyledProgress = styled.div(_templateObject, themeProp('progressFontSize', progressFontSize), themeProp('progressHeight', progressHeight), themeProp('progressBg', progressBg), borderRadius(themeProp('progressBorderRadius', progressBorderRadius)), boxShadow(themeProp('progressBoxShadow', progressBoxShadow)));

var Progress = function Progress(props) {
  return props.children ? cloneElement(React.createElement(StyledProgress, null), props) : React.createElement(
    StyledProgress,
    null,
    React.createElement(ProgressBar, {
      width: props.width,
      striped: props.striped,
      animated: props.animated
    })
  );
};

Progress.Bar = ProgressBar;

Progress.defaultProps = {};
Progress.propTypes = {};

export default Progress;

==> styled-bootstrap-0.1.9.tgz: package/lib/Progress/Progress.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: flex;\n  overflow: hidden; // force rounded corners by cropping it\n  font-size: ', ';\n  line-height: ', ';\n  text-align: center;\n  background-color: ', ';\n  ', ';\n  ', ';\n'], ['\n  display: flex;\n  overflow: hidden; // force rounded corners by cropping it\n  font-size: ', ';\n  line-height: ', ';\n  text-align: center;\n  background-color: ', ';\n  ', ';\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React, { cloneElement } from 'react';
import styled from 'styled-components';
// import PropTypes from 'prop-types';

import { borderRadius } from '../utils/border-radius';
import { boxShadow } from '../utils/box-shadow';

import ProgressBar from './ProgressBar';

import themeProp from '../utils/theme';

import { progressHeight, progressFontSize, progressBg, progressBorderRadius, progressBoxShadow } from './default-theme';

var StyledProgress = styled.div(_templateObject, themeProp('progressFontSize', progressFontSize), themeProp('progressHeight', progressHeight), themeProp('progressBg', progressBg), borderRadius(themeProp('progressBorderRadius', progressBorderRadius)), boxShadow(themeProp('progressBoxShadow', progressBoxShadow)));

var Progress = function Progress(props) {
  return props.children ? cloneElement(React.createElement(StyledProgress, null), props) : React.createElement(
    StyledProgress,
    null,
    React.createElement(ProgressBar, {
      width: props.width,
      striped: props.striped,
      animated: props.animated
    })
  );
};

Progress.Bar = ProgressBar;

Progress.defaultProps = {};
Progress.propTypes = {};

export default Progress;
